## SPOOX

<br>
  
**SPOOX – SPlit lOOp eXpand**

A terminal-integrated, LLM-powered multi-agent system (MAS) designed to assist developers directly within their terminal.
_Spoox CLI_ provides intelligent assistance for OS tasks, server management workflows, and software engineering challenges.
The architectures of these agent systems are based on the _spoox_ MAS design framework,
a generic architectural framework for multi-agent topology and communication design. 

Several differently scaled terminal MAS variants have been developed and are accessible through a terminal CLI: _spoox-s_, _spoox-m_, and _spoox-l_.
The spoox-m variant achieved first place on the [Terminal Bench leaderboard](https://www.tbench.ai/leaderboard/terminal-bench/2.0?models=GPT-5-Mini) 
for the gpt-5-mini model and is therefore used as the default configuration for the _spoox CLI_.


More information and code are available on the [Spoox GitHub repository](https://github.com/plaume8/spoox).

<br>

Authors: 
[Linus Sander](mailto:linus.sander@tum.de),
[Fengjunjie Pan](mailto:f.pan@tum.de),
[Alois Knoll](mailto:k@tum.de)

